==> data-refinery-0.2.2.tar.gz: data-refinery-0.2.2/datarefinery/CombineOperations.py <==
# Copyright 2017 BBVA
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import copy
from functools import reduce

from datarefinery.tuple.TupleDSL import compose


def parallel(*tupleOperations):
    def _no_operations(inp=None, err=None):
        return None, "No operations to perform"

    def _no_affect(inp, err=None):
        if inp is not None:
            i = copy.deepcopy(inp)
        else:
            i = None
        if err is not None:
            e = copy.deepcopy(err)
        else:
            e = None
        return i, e

    def _apply(inp, err=None):
        def _reductor(acc, re):
            (i, e) = acc
            (o, er) = re
            i.update(o)
            if er is not None and e is not None:
                e.update(er)
            elif er is not None:
                e = er
            return i, e
        inmutable = map(lambda x: compose(_no_affect, x), tupleOperations)
        results = map(lambda x: x(inp, err), inmutable)
        return reduce(_reductor, results, ({}, None))

    some_params = any(map(lambda x: x is not None, tupleOperations))
    if tupleOperations is not None and some_params:
        return _apply
    return _no_operations


def secuential(*tuple_operations):
    def _no_operations(inp=None, err=None):
        return None, "No operations to perform"

    def _no_affect(inp, err=None):
        if inp is not None:
            i = copy.deepcopy(inp)
        else:
            i = None
        if err is not None:
            e = copy.deepcopy(err)
        else:
            e = None
        return i, e

    def _apply(inp, err=None):
        for operation in tuple_operations:
            inp, err = operation(inp, err)
        return inp, err

    some_params = any(map(lambda x: x is not None, tuple_operations))
    if tuple_operations is not None and some_params:
        return compose(_no_affect, _apply)
    return _no_operations

==> data-refinery-0.2.3.tar.gz: data-refinery-0.2.3/datarefinery/CombineOperations.py <==
# Copyright 2017 BBVA
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import copy
from functools import reduce

from datarefinery.tuple.TupleDSL import compose


def parallel(*tupleOperations):
    def _no_operations(inp=None, err=None):
        return None, "No operations to perform"

    def _no_affect(inp, err=None):
        if inp is not None:
            i = copy.deepcopy(inp)
        else:
            i = None
        if err is not None:
            e = copy.deepcopy(err)
        else:
            e = None
        return i, e

    def _apply(inp, err=None):
        def _reductor(acc, re):
            (i, e) = acc
            (o, er) = re
            if o is not None and i is not None:
                i.update(o)
            elif o is not None:
                i = o
            if er is not None and e is not None:
                e.update(er)
            elif er is not None:
                e = er
            return i, e
        inmutable = map(lambda x: compose(_no_affect, x), tupleOperations)
        results = map(lambda x: x(inp, err), inmutable)
        return reduce(_reductor, results, (None, None))

    some_params = any(map(lambda x: x is not None, tupleOperations))
    if tupleOperations is not None and some_params:
        return _apply
    return _no_operations


def secuential(*tuple_operations):
    def _no_operations(inp=None, err=None):
        return None, "No operations to perform"

    def _no_affect(inp, err=None):
        if inp is not None:
            i = copy.deepcopy(inp)
        else:
            i = None
        if err is not None:
            e = copy.deepcopy(err)
        else:
            e = None
        return i, e

    def _apply(inp, err=None):
        for operation in tuple_operations:
            inp, err = operation(inp, err)
        return inp, err

    some_params = any(map(lambda x: x is not None, tuple_operations))
    if tuple_operations is not None and some_params:
        return compose(_no_affect, _apply)
    return _no_operations
